@@ -1,22 +1,23 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
 /*
- * ea-minicard-view.c
- * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
- * Author:  Leon Zhang < leon.zhang@sun.com>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * General Public License for more details.
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Leon Zhang < leon.zhang@sun.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -28,14 +29,13 @@
 #include "eab-gui-util.h"
 #include "e-addressbook-view.h"
 
-static const char * action_name[] = {
+static const gchar * action_name[] = {
 	N_("New Contact"),
 	N_("New Contact List")
 };
 
-
-static G_CONST_RETURN gchar* ea_minicard_view_get_name (AtkObject *accessible);
-static G_CONST_RETURN gchar* ea_minicard_view_get_description (AtkObject *accessible);
+static G_CONST_RETURN gchar * ea_minicard_view_get_name (AtkObject *accessible);
+static G_CONST_RETURN gchar * ea_minicard_view_get_description (AtkObject *accessible);
 
 static void ea_minicard_view_class_init (EaMinicardViewClass *klass);
 
@@ -57,8 +57,8 @@ static gboolean selection_interface_is_child_selected (AtkSelection *selection,
 static void atk_action_interface_init (AtkActionIface *iface);
 static gboolean atk_action_interface_do_action (AtkAction *iface, gint i);
 static gint atk_action_interface_get_n_action (AtkAction *iface);
-static G_CONST_RETURN gchar* atk_action_interface_get_description (AtkAction *iface, gint i);
-static G_CONST_RETURN gchar* atk_action_interface_get_name (AtkAction *iface, gint i);
+static G_CONST_RETURN gchar * atk_action_interface_get_description (AtkAction *iface, gint i);
+static G_CONST_RETURN gchar * atk_action_interface_get_name (AtkAction *iface, gint i);
 
 static gpointer parent_class = NULL;
 
@@ -134,7 +134,7 @@ ea_minicard_view_class_init (EaMinicardViewClass *klass)
 	class->ref_child = ea_minicard_view_ref_child;
 }
 
-static G_CONST_RETURN gchar*
+static G_CONST_RETURN gchar *
 ea_minicard_view_get_name (AtkObject *accessible)
 {
 	EReflow *reflow;
@@ -159,8 +159,8 @@ ea_minicard_view_get_name (AtkObject *accessible)
 		source_name="";
 
 	string = g_strdup_printf (ngettext ("current address book folder %s has %d card",
-	                          "current address book folder %s has %d cards",
-	                          reflow->count), source_name, reflow->count);
+				  "current address book folder %s has %d cards",
+				  reflow->count), source_name, reflow->count);
 
 	ATK_OBJECT_CLASS (parent_class)->set_name (accessible, string);
 	g_free (string);
@@ -168,14 +168,14 @@ ea_minicard_view_get_name (AtkObject *accessible)
 	return accessible->name;
 }
 
-static G_CONST_RETURN gchar*
+static G_CONST_RETURN gchar *
 ea_minicard_view_get_description (AtkObject *accessible)
 {
 	g_return_val_if_fail (EA_IS_MINICARD_VIEW(accessible), NULL);
 	if (accessible->description)
 		return accessible->description;
 
-	return _("evolution addressbook");
+	return _("evolution address book");
 }
 
 AtkObject*
@@ -389,7 +389,7 @@ static gboolean atk_action_interface_do_action (AtkAction *action, gint i)
 			eab_show_contact_list_editor (book, contact, TRUE, TRUE);
 			break;
 		default:
-                	return_value = FALSE;
+			return_value = FALSE;
 			break;
 	}
 	g_object_unref (book);
@@ -402,13 +402,13 @@ static gint atk_action_interface_get_n_action (AtkAction *iface)
 	return G_N_ELEMENTS (action_name);
 }
 
-static G_CONST_RETURN gchar*
+static G_CONST_RETURN gchar *
 atk_action_interface_get_description (AtkAction *iface, gint i)
 {
 	return atk_action_interface_get_name (iface, i);
 }
 
-static G_CONST_RETURN gchar*
+static G_CONST_RETURN gchar *
 atk_action_interface_get_name (AtkAction *iface, gint i)
 {
 	if( i >= G_N_ELEMENTS (action_name) || i < 0)
