@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -27,7 +27,7 @@
 #include <misc/e-canvas.h>
 #include <glib/gi18n.h>
 
-#include "eab-marshal.h"
+#include "e-util/e-util.h"
 #include "e-minicard-view-widget.h"
 
 static void e_minicard_view_widget_init		 (EMinicardViewWidget		 *widget);
@@ -164,7 +164,7 @@ e_minicard_view_widget_class_init (EMinicardViewWidgetClass *class)
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (EMinicardViewWidgetClass, right_click),
 			      NULL, NULL,
-			      eab_marshal_INT__POINTER,
+			      e_marshal_INT__POINTER,
 			      G_TYPE_INT, 1, G_TYPE_POINTER);
 }
 
@@ -303,7 +303,7 @@ selection_change (ESelectionModel *esm, EMinicardViewWidget *widget)
 }
 
 static void
-selection_row_change (ESelectionModel *esm, int row, EMinicardViewWidget *widget)
+selection_row_change (ESelectionModel *esm, gint row, EMinicardViewWidget *widget)
 {
 	selection_change (esm, widget);
 }
@@ -339,7 +339,6 @@ e_minicard_view_widget_style_set (GtkWidget *widget, GtkStyle *previous_style)
 		GTK_WIDGET_CLASS(parent_class)->style_set (widget, previous_style);
 }
 
-
 static void
 e_minicard_view_widget_realize (GtkWidget *widget)
 {
@@ -447,7 +446,7 @@ e_minicard_view_widget_real_focus_in_event(GtkWidget *widget, GdkEventFocus *eve
 	if (!canvas->focused_item) {
 		EReflow *reflow = E_REFLOW (view->emv);
 		if (reflow->count) {
-			int unsorted = e_sorter_sorted_to_model (E_SORTER (reflow->sorter), 0);
+			gint unsorted = e_sorter_sorted_to_model (E_SORTER (reflow->sorter), 0);
 
 			if (unsorted != -1)
 				canvas->focused_item = reflow->items [unsorted];
