@@ -12,7 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -39,7 +39,6 @@
 #include <libecal/e-cal-time-util.h>
 #include <libecal/e-cal-component.h>
 
-
 #ifdef HAVE_LIBNOTIFY
 #include <libnotify/notify.h>
 #endif
@@ -76,8 +75,8 @@ static GList *tray_icons_list = NULL;
 
 /* Top Tray Image */
 static GtkStatusIcon *tray_icon = NULL;
-static int tray_blink_id = -1;
-static int tray_blink_countdown = 0;
+static gint tray_blink_id = -1;
+static gint tray_blink_countdown = 0;
 static AlarmNotify *an;
 
 /* Structure that stores a client we are monitoring */
@@ -150,7 +149,6 @@ static void popup_notification (time_t trigger, CompQueuedAlarms *cqa,
 static void query_objects_changed_cb (ECal *client, GList *objects, gpointer data);
 static void query_objects_removed_cb (ECal *client, GList *objects, gpointer data);
 
-static void remove_client_alarms (ClientAlarms *ca);
 static void update_cqa (CompQueuedAlarms *cqa, ECalComponent *comp);
 static void update_qa (ECalComponentAlarms *alarms, QueuedAlarm *qa);
 static void tray_list_remove_cqa (CompQueuedAlarms *cqa);
@@ -521,7 +519,7 @@ add_component_alarms (ClientAlarms *ca, ECalComponentAlarms *alarms)
 static void
 load_alarms (ClientAlarms *ca, time_t start, time_t end)
 {
-	char *str_query, *iso_start, *iso_end;
+	gchar *str_query, *iso_start, *iso_end;
 
 	d(printf("%s:%d (load_alarms) \n",__FILE__, __LINE__));
 
@@ -876,7 +874,7 @@ query_objects_removed_cb (ECal *client, GList *objects, gpointer data)
  * compued with respect to the current time.
  */
 static void
-create_snooze (CompQueuedAlarms *cqa, gpointer alarm_id, int snooze_mins)
+create_snooze (CompQueuedAlarms *cqa, gpointer alarm_id, gint snooze_mins)
 {
 	QueuedAlarm *orig_qa;
 	time_t t;
@@ -905,8 +903,8 @@ create_snooze (CompQueuedAlarms *cqa, gpointer alarm_id, int snooze_mins)
 static void
 edit_component (ECal *client, ECalComponent *comp)
 {
-	const char *uid;
-	const char *uri;
+	const gchar *uid;
+	const gchar *uri;
 	ECalSourceType source_type;
 	CORBA_Environment ev;
 	GNOME_Evolution_Calendar_CompEditorFactory factory;
@@ -921,8 +919,8 @@ edit_component (ECal *client, ECalComponent *comp)
 
 	/* Get the factory */
 	CORBA_exception_init (&ev);
-	factory = bonobo_activation_activate_from_id ("OAFIID:GNOME_Evolution_Calendar_CompEditorFactory:" BASE_VERSION,
-						      0, NULL, &ev);
+	factory = bonobo_activation_activate_from_id (
+		(Bonobo_ActivationID) "OAFIID:GNOME_Evolution_Calendar_CompEditorFactory:" BASE_VERSION, 0, NULL, &ev);
 
 	if (BONOBO_EX (&ev)) {
 		e_error_run (NULL, "editor-error", bonobo_exception_get_text (&ev), NULL);
@@ -939,7 +937,7 @@ edit_component (ECal *client, ECalComponent *comp)
 		corba_type = GNOME_Evolution_Calendar_CompEditorFactory_EDITOR_MODE_EVENT;
 	}
 
-	GNOME_Evolution_Calendar_CompEditorFactory_editExisting (factory, uri, (char *) uid, corba_type, &ev);
+	GNOME_Evolution_Calendar_CompEditorFactory_editExisting (factory, uri, (gchar *) uid, corba_type, &ev);
 
 	if (BONOBO_EX (&ev))
 		e_error_run (NULL, "editor-error", bonobo_exception_get_text (&ev), NULL);
@@ -951,9 +949,9 @@ edit_component (ECal *client, ECalComponent *comp)
 }
 
 typedef struct {
-	char *summary;
-	char *description;
-	char *location;
+	gchar *summary;
+	gchar *description;
+	gchar *location;
 	gboolean blink_state;
 	gboolean snooze_set;
 	gint blink_id;
@@ -1010,7 +1008,7 @@ free_tray_icon_data (TrayIconData *tray_data)
 static void
 on_dialog_objs_removed_async (struct _query_msg *msg)
 {
-	const char *our_uid;
+	const gchar *our_uid;
 	GList *l;
 	TrayIconData *tray_data;
 	ECal *client;
@@ -1026,7 +1024,7 @@ on_dialog_objs_removed_async (struct _query_msg *msg)
 	g_return_if_fail (our_uid && *our_uid);
 
 	for (l = objects; l != NULL; l = l->next) {
-		const char *uid = l->data;
+		const gchar *uid = l->data;
 
 		if (!uid)
 			continue;
@@ -1198,7 +1196,7 @@ tray_list_remove_data (TrayIconData *data)
 }
 
 static void
-notify_dialog_cb (AlarmNotifyResult result, int snooze_mins, gpointer data)
+notify_dialog_cb (AlarmNotifyResult result, gint snooze_mins, gpointer data)
 {
 	TrayIconData *tray_data = data;
 
@@ -1346,8 +1344,6 @@ tray_icon_clicked_cb (GtkWidget *widget, GdkEventButton *event, gpointer user_da
 				g_source_remove (tray_blink_id);
 			tray_blink_id = -1;
 
-
-
 			gtk_status_icon_set_visible (tray_icon, FALSE);
 			g_object_unref (tray_icon);
 			tray_icon = NULL;
@@ -1408,7 +1404,6 @@ tray_icon_blink_cb (gpointer data)
 	return tray_blink_countdown > 0;
 }
 
-
 /* Add a new data to tray list */
 
 static void
@@ -1438,11 +1433,11 @@ display_notification (time_t trigger, CompQueuedAlarms *cqa,
 {
 	QueuedAlarm *qa;
 	ECalComponent *comp;
-	const char *summary, *description, *location;
+	const gchar *summary, *description, *location;
 	TrayIconData *tray_data;
 	ECalComponentText text;
 	GSList *text_list;
-	char *str, *start_str, *end_str, *alarm_str, *time_str;
+	gchar *str, *start_str, *end_str, *alarm_str, *time_str;
 	icaltimezone *current_zone;
 	ECalComponentOrganizer organiser;
 
@@ -1460,7 +1455,7 @@ display_notification (time_t trigger, CompQueuedAlarms *cqa,
 	if (text.value)
 		summary = text.value;
 	else
-	        summary = _("No summary available.");
+		summary = _("No summary available.");
 
 	e_cal_component_get_description_list (comp, &text_list);
 
@@ -1479,7 +1474,7 @@ display_notification (time_t trigger, CompQueuedAlarms *cqa,
 	e_cal_component_get_location (comp, &location);
 
 	if (!location)
-	        location = _("No location information available.");
+		location = _("No location information available.");
 
 	/* create the tray icon */
 	if (tray_icon == NULL) {
@@ -1522,7 +1517,7 @@ display_notification (time_t trigger, CompQueuedAlarms *cqa,
 	tray_list_add_new (tray_data);
 
 	if (g_list_length (tray_icons_list) > 1) {
-		char *tip;
+		gchar *tip;
 
 		tip =  g_strdup_printf (_("You have %d alarms"), g_list_length (tray_icons_list));
 		gtk_status_icon_set_tooltip_text (tray_icon, tip);
@@ -1556,17 +1551,17 @@ display_notification (time_t trigger, CompQueuedAlarms *cqa,
 #ifdef HAVE_LIBNOTIFY
 static void
 popup_notification (time_t trigger, CompQueuedAlarms *cqa,
-	            gpointer alarm_id, gboolean use_description)
+		    gpointer alarm_id, gboolean use_description)
 {
 	QueuedAlarm *qa;
 	ECalComponent *comp;
-	const char *summary, *location;
+	const gchar *summary, *location;
 	ECalComponentText text;
-	char *str, *start_str, *end_str, *alarm_str, *time_str;
+	gchar *str, *start_str, *end_str, *alarm_str, *time_str;
 	icaltimezone *current_zone;
 	ECalComponentOrganizer organiser;
 	NotifyNotification *n;
-	char *body;
+	gchar *body;
 
 	d(printf("%s:%d (popup_notification)\n",__FILE__, __LINE__));
 
@@ -1581,11 +1576,10 @@ popup_notification (time_t trigger, CompQueuedAlarms *cqa,
 	e_cal_component_get_summary (comp, &text);
 	e_cal_component_get_organizer (comp, &organiser);
 
-
 	if (text.value)
 		summary = text.value;
 	else
-	        summary = _("No summary available.");
+		summary = _("No summary available.");
 
 	e_cal_component_get_location (comp, &location);
 
@@ -1624,7 +1618,6 @@ popup_notification (time_t trigger, CompQueuedAlarms *cqa,
 	g_free (time_str);
 	g_free (str);
 
-
 }
 #endif
 
@@ -1637,7 +1630,7 @@ audio_notification (time_t trigger, CompQueuedAlarms *cqa,
 	ECalComponent *comp;
 	ECalComponentAlarm *alarm;
 	icalattach *attach;
-	int	flag = 0;
+	gint	flag = 0;
 
 	d(printf("%s:%d (audio_notification)\n",__FILE__, __LINE__));
 
@@ -1653,7 +1646,7 @@ audio_notification (time_t trigger, CompQueuedAlarms *cqa,
 	e_cal_component_alarm_free (alarm);
 
 	if (attach && icalattach_get_is_url (attach)) {
-		const char *url;
+		const gchar *url;
 
 		url = icalattach_get_url (attach);
 
@@ -1703,11 +1696,11 @@ mail_notification (time_t trigger, CompQueuedAlarms *cqa, gpointer alarm_id)
 
 /* Performs notification of a procedure alarm */
 static gboolean
-procedure_notification_dialog (const char *cmd, const char *url)
+procedure_notification_dialog (const gchar *cmd, const gchar *url)
 {
 	GtkWidget *dialog, *label, *checkbox;
-	char *str;
-	int btn;
+	gchar *str;
+	gint btn;
 
 	d(printf("%s:%d (procedure_notification_dialog)\n",__FILE__, __LINE__));
 
@@ -1756,8 +1749,8 @@ procedure_notification (time_t trigger, CompQueuedAlarms *cqa, gpointer alarm_id
 	ECalComponentAlarm *alarm;
 	ECalComponentText description;
 	icalattach *attach;
-	const char *url;
-	char *cmd;
+	const gchar *url;
+	gchar *cmd;
 	gboolean result = TRUE;
 
 	d(printf("%s:%d (procedure_notification)\n",__FILE__, __LINE__));
@@ -1790,12 +1783,12 @@ procedure_notification (time_t trigger, CompQueuedAlarms *cqa, gpointer alarm_id
 	if (description.value)
 		cmd = g_strconcat (url, " ", description.value, NULL);
 	else
-		cmd = (char *) url;
+		cmd = (gchar *) url;
 
 	if (procedure_notification_dialog (cmd, url))
 		result = g_spawn_command_line_async (cmd, NULL);
 
-	if (cmd != (char *) url)
+	if (cmd != (gchar *) url)
 		g_free (cmd);
 
 	icalattach_unref (attach);
@@ -2050,15 +2043,14 @@ remove_comp_by_id (gpointer key, gpointer value, gpointer userdata) {
 
 	d(printf("%s:%d (remove_comp_by_id)\n",__FILE__, __LINE__));
 
-/* 	if (!g_hash_table_size (ca->uid_alarms_hash)) */
-/* 		return; */
+/*	if (!g_hash_table_size (ca->uid_alarms_hash)) */
+/*		return; */
 
 	remove_cqa (ca, (ECalComponentId *)key, (CompQueuedAlarms *) value);
 
 	return TRUE;
 }
 
-
 /* Removes all the alarms queued for a particular calendar client */
 static void
 remove_client_alarms (ClientAlarms *ca)
@@ -2169,7 +2161,7 @@ update_cqa (CompQueuedAlarms *cqa, ECalComponent *newcomp)
 	/* Update auids in Queued Alarms*/
 	for (qa_list = cqa->queued_alarms; qa_list; qa_list = qa_list->next) {
 		QueuedAlarm *qa = qa_list->data;
-		char *check_auid = (char *) qa->instance->auid;
+		gchar *check_auid = (gchar *) qa->instance->auid;
 		ECalComponentAlarm *alarm;
 
 		alarm = e_cal_component_get_alarm (newcomp, check_auid);
@@ -2207,8 +2199,8 @@ update_qa (ECalComponentAlarms *alarms, QueuedAlarm *qa)
 	d(printf("%s:%d (update_qa)\n",__FILE__, __LINE__));
 	for (instance_list = alarms->alarms; instance_list; instance_list = instance_list->next) {
 		al_inst = instance_list->data;
-		if (al_inst->trigger == qa->orig_trigger) {  /* FIXME if two or more alarm instances (audio, note) 									  for same component have same trigger */
-			g_free ((char *) qa->instance->auid);
+		if (al_inst->trigger == qa->orig_trigger) {  /* FIXME if two or more alarm instances (audio, note)									  for same component have same trigger */
+			g_free ((gchar *) qa->instance->auid);
 			qa->instance->auid = g_strdup (al_inst->auid);
 			break;
 		}
