@@ -12,7 +12,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -113,11 +113,11 @@ struct _CompEditorPrivate {
 
 	CalObjModType mod;
 
- 	gboolean existing_org;
- 	gboolean user_org;
+	gboolean existing_org;
+	gboolean user_org;
 	gboolean is_group_item;
 
- 	gboolean warned;
+	gboolean warned;
 };
 
 enum {
@@ -190,99 +190,109 @@ attachment_store_changed_cb (CompEditor *editor)
 	comp_editor_set_changed (editor, TRUE);
 }
 
+static void
+attachment_save_finished (EAttachmentStore *store,
+                          GAsyncResult *result,
+                          gpointer user_data)
+{
+	GtkWidget *dialog;
+	const gchar *primary_text;
+	gchar **uris;
+	GError *error = NULL;
+
+	struct {
+		gchar **uris;
+		gboolean done;
+		GtkWindow *parent;
+	} *status = user_data;
+
+	uris = e_attachment_store_save_finish (store, result, &error);
+
+	status->uris = uris;
+	status->done = TRUE;
+
+	if (uris != NULL)
+		goto exit;
+
+	/* Ignore cancellations. */
+	if (g_error_matches (error, G_IO_ERROR, G_IO_ERROR_CANCELLED))
+		goto exit;
+
+	primary_text = _("Could not save attachments");
+
+	dialog = gtk_message_dialog_new_with_markup (
+		status->parent, GTK_DIALOG_DESTROY_WITH_PARENT,
+		GTK_MESSAGE_ERROR, GTK_BUTTONS_OK,
+		"<big><b>%s</b></big>", primary_text);
+
+	gtk_message_dialog_format_secondary_text (
+		GTK_MESSAGE_DIALOG (dialog), "%s", error->message);
+
+	gtk_dialog_run (GTK_DIALOG (dialog));
+
+	gtk_widget_destroy (dialog);
+
+exit:
+	if (error != NULL)
+		g_error_free (error);
+
+	g_object_unref (status->parent);
+}
+
 static GSList *
 get_attachment_list (CompEditor *editor)
 {
 	EAttachmentStore *store;
 	EAttachmentView *view;
-	GtkTreeModel *model;
-	GtkTreeIter iter;
+	GFile *destination;
 	GSList *list = NULL;
-	const char *comp_uid = NULL;
-	const char *local_store = e_cal_get_local_attachment_store (editor->priv->client);
-	gboolean valid;
-	int ticker=0;
+	const gchar *comp_uid = NULL;
+	const gchar *local_store;
+	gchar *uri;
+	gint ii;
 
-	e_cal_component_get_uid (editor->priv->comp, &comp_uid);
+	struct {
+		gchar **uris;
+		gboolean done;
+		GtkWindow *parent;
+	} status;
+
+	status.uris = NULL;
+	status.done = FALSE;
+	status.parent = g_object_ref (editor);
 
 	view = E_ATTACHMENT_VIEW (editor->priv->attachment_view);
 	store = e_attachment_view_get_store (view);
 
-	model = GTK_TREE_MODEL (store);
-	valid = gtk_tree_model_get_iter_first (model, &iter);
+	local_store = e_cal_get_local_attachment_store (editor->priv->client);
+	e_cal_component_get_uid (editor->priv->comp, &comp_uid);
+	uri = g_build_path ("/", local_store, comp_uid, NULL);
+	destination = g_file_new_for_uri (uri);
+	g_free (uri);
 
-	while (valid) {
-		EAttachment *attachment;
-		CamelDataWrapper *wrapper;
-		CamelMimePart *mime_part;
-		CamelStream *stream;
-		char *attach_file_url;
-		char *safe_fname, *utf8_safe_fname;
-		char *filename;
-		gint column_id;
+	e_attachment_store_save_async (
+		store, destination, (GAsyncReadyCallback)
+		attachment_save_finished, &status);
 
-		column_id = E_ATTACHMENT_STORE_COLUMN_ATTACHMENT;
-		gtk_tree_model_get (model, &iter, column_id, &attachment, -1);
-		mime_part = e_attachment_get_mime_part (attachment);
-		g_object_unref (attachment);
+	g_object_unref (destination);
 
-		valid = gtk_tree_model_iter_next (model, &iter);
+	/* We can't return until we have results, so crank
+	 * the main loop until the callback gets triggered. */
+	while (!status.done)
+		gtk_main_iteration ();
 
-		if (mime_part == NULL)
-			continue;
+	if (status.uris == NULL)
+		return NULL;
 
-		wrapper = camel_medium_get_content_object (CAMEL_MEDIUM (mime_part));
-
-		/* Extract the content from the stream and write it down
-		 * as a mime part file into the directory denoting the
-		 * calendar source */
-		utf8_safe_fname = camel_file_util_safe_filename (camel_mime_part_get_filename (mime_part));
-
-		/* It is absolutely fine to get a NULL from the filename of 
-		 * mime part. We assume that it is named "Attachment"
-		 * in mailer. I'll do that with a ticker */
-		if (!utf8_safe_fname)
-			safe_fname = g_strdup_printf ("%s-%d", _("attachment"), ticker++);
-		else {
-			safe_fname = g_filename_from_utf8 ((const char *) utf8_safe_fname, -1, NULL, NULL, NULL);
-			g_free (utf8_safe_fname);
-		}
-		filename = g_strdup_printf ("%s-%s", comp_uid, safe_fname);
-
-		attach_file_url = g_build_path ("/", local_store, filename, NULL);
-
-		g_free (filename);
-		g_free (safe_fname);
-
-		/* do not overwrite existing files, this will result in truncation */
-		filename = g_filename_from_uri (attach_file_url, NULL, NULL);
-		if (!g_file_test (filename, G_FILE_TEST_EXISTS)) {
-			stream = camel_stream_fs_new_with_name(filename, O_RDWR|O_CREAT|O_TRUNC, 0600);
-			if (!stream) {
-				/* TODO handle error conditions */
-				g_message ("DEBUG: could not open the file to write\n");
-				g_free (attach_file_url);
-				g_free (filename);
-				continue;
-			}
-
-			if (camel_data_wrapper_decode_to_stream (wrapper, (CamelStream *) stream) == -1) {
-				g_free (attach_file_url);
-				camel_stream_close (stream);
-				camel_object_unref (stream);
-				g_message ("DEBUG: could not write to file\n");
-			}
-
-			camel_stream_close (stream);
-			camel_object_unref (stream);
-		}
-
-		list = g_slist_append (list, g_strdup (attach_file_url));
-		g_free (attach_file_url);
-		g_free (filename);
+	/* Transfer the URI strings to the GSList. */
+	for (ii = 0; status.uris[ii] != NULL; ii++) {
+		list = g_slist_prepend (list, status.uris[ii]);
+		status.uris[ii] = NULL;
 	}
 
-	return list;
+	g_free (status.uris);
+
+	return g_slist_reverse (list);
 }
 
 /* This sets the focus to the toplevel, so any field being edited is committed.
@@ -298,7 +308,7 @@ static void
 listen_for_changes (CompEditor *editor)
 {
 	CompEditorPrivate *priv;
-	const char *uid = NULL;
+	const gchar *uid = NULL;
 
 	priv = editor->priv;
 
@@ -318,7 +328,7 @@ listen_for_changes (CompEditor *editor)
 		e_cal_component_get_uid (priv->comp, &uid);
 
 	if (uid) {
-		char *query;
+		gchar *query;
 
 		query = g_strdup_printf ("(uid? \"%s\")", uid);
 		e_cal_get_query (priv->source_client, query, &priv->view, NULL);
@@ -356,7 +366,7 @@ save_comp (CompEditor *editor)
 	gboolean result;
 	GError *error = NULL;
 	GHashTable *timezones;
-	const char *orig_uid;
+	const gchar *orig_uid;
 	icalcomponent *icalcomp;
 
 	priv = editor->priv;
@@ -423,7 +433,6 @@ save_comp (CompEditor *editor)
 		if (e_cal_component_has_recurrences (priv->comp) && priv->mod == CALOBJ_MOD_ALL)
 			comp_util_sanitize_recurrence_master (priv->comp, priv->client);
 
-
 		if (priv->mod == CALOBJ_MOD_THIS) {
 			e_cal_component_set_rdate_list (priv->comp, NULL);
 			e_cal_component_set_rrule_list (priv->comp, NULL);
@@ -449,7 +458,7 @@ save_comp (CompEditor *editor)
 		icalproperty *icalprop;
 		icalprop = icalcomponent_get_first_property (icalcomp, ICAL_X_PROPERTY);
 		while (icalprop) {
-			const char *x_name;
+			const gchar *x_name;
 
 			x_name = icalproperty_get_x_name (icalprop);
 			if (!strcmp (x_name, "X-EVOLUTION-OPTIONS-DELAY")) {
@@ -534,8 +543,8 @@ save_comp_with_send (CompEditor *editor)
 		return FALSE;
 
 	if ((delegate && !e_cal_get_save_schedules (priv->client)) || (send && send_component_dialog ((GtkWindow *) editor, priv->client, priv->comp, !priv->existing_org, &strip_alarms))) {
- 		if ((itip_organizer_is_user (priv->comp, priv->client) || itip_sentby_is_user (priv->comp, priv->client))) {
- 			if (e_cal_component_get_vtype (priv->comp) == E_CAL_COMPONENT_JOURNAL)
+		if ((itip_organizer_is_user (priv->comp, priv->client) || itip_sentby_is_user (priv->comp, priv->client))) {
+			if (e_cal_component_get_vtype (priv->comp) == E_CAL_COMPONENT_JOURNAL)
 				return comp_editor_send_comp (editor, E_CAL_COMPONENT_METHOD_PUBLISH, strip_alarms);
 			else
 				return comp_editor_send_comp (editor, E_CAL_COMPONENT_METHOD_REQUEST, strip_alarms);
@@ -546,7 +555,7 @@ save_comp_with_send (CompEditor *editor)
 			if (delegate)
 				return comp_editor_send_comp (editor, E_CAL_COMPONENT_METHOD_REPLY, strip_alarms);
 		}
- 	}
+	}
 
 	return TRUE;
 }
@@ -798,7 +807,7 @@ action_save_cb (GtkAction *action,
 		priv->mod = CALOBJ_MOD_THIS;
 
 	comp = comp_editor_get_current_comp (editor, &correct);
-		
+
 	e_cal_component_get_summary (comp, &text);
 	g_object_unref (comp);
 
@@ -817,7 +826,7 @@ action_save_cb (GtkAction *action,
 		delegate = flags & COMP_EDITOR_DELEGATE;
 
 		if (delegate && !remove_event_dialog (priv->client, priv->comp, GTK_WINDOW (editor))) {
-			const char *uid = NULL; 
+			const gchar *uid = NULL;
 			GError *error = NULL;
 
 			e_cal_component_get_uid (priv->comp, &uid);
@@ -1730,7 +1739,6 @@ comp_editor_show_help (CompEditor *editor)
 	e_display_help (GTK_WINDOW (editor), class->help_section);
 }
 
-
 /* Closes the dialog box and emits the appropriate signals */
 static void
 close_dialog (CompEditor *editor)
@@ -1938,7 +1946,6 @@ comp_editor_set_flags (CompEditor *editor,
 	g_object_notify (G_OBJECT (editor), "flags");
 }
 
-
 CompEditorFlags
 comp_editor_get_flags (CompEditor *editor)
 {
@@ -2078,7 +2085,7 @@ page_unmapped_cb (GtkWidget *page_widget,
 void
 comp_editor_append_page (CompEditor *editor,
 			 CompEditorPage *page,
-			 const char *label,
+			 const gchar *label,
 			 gboolean add)
 {
 	CompEditorPrivate *priv;
@@ -2239,11 +2246,52 @@ comp_editor_get_client (CompEditor *editor)
 }
 
 static void
-set_attachment_list (CompEditor *editor, GSList *attach_list)
+attachment_loaded_cb (EAttachment *attachment,
+                      GAsyncResult *result,
+                      GtkWindow *parent)
+{
+	GFileInfo *file_info;
+	const gchar *display_name;
+	const gchar *uid;
+
+	/* Prior to 2.27.2, attachment files were named:
+	 *
+	 *     <component-uid> '-' <actual-filename>
+	 *     -------------------------------------
+	 *              (one long filename)
+	 *
+	 * Here we fix the display name if this form is detected so we
+	 * don't show the component UID in the user interface.  If the
+	 * user saves changes in the editor, the attachment will be
+	 * written to disk as:
+	 *
+	 *     <component-uid> / <actual-filename>
+	 *     ---------------   -----------------
+	 *       (directory)      (original name)
+	 *
+	 * So this is a lazy migration from the old form to the new.
+	 */
+
+	file_info = e_attachment_get_file_info (attachment);
+	display_name = g_file_info_get_display_name (file_info);
+	uid = g_object_get_data (G_OBJECT (attachment), "uid");
+
+	if (g_str_has_prefix (display_name, uid)) {
+		g_file_info_set_display_name (
+			file_info, display_name + strlen (uid) + 1);
+		g_object_notify (G_OBJECT (attachment), "file-info");
+	}
+
+	e_attachment_load_handle_error (attachment, result, parent);
+}
+
+static void
+set_attachment_list (CompEditor *editor, GSList *uri_list)
 {
 	EAttachmentStore *store;
 	EAttachmentView *view;
-	GSList *iter = NULL;
+	const gchar *uid = NULL;
+	GSList *iter;
 
 	view = E_ATTACHMENT_VIEW (editor->priv->attachment_view);
 	store = e_attachment_view_get_store (view);
@@ -2256,15 +2304,22 @@ set_attachment_list (CompEditor *editor, GSList *attach_list)
 		return;
 	}
 
-	for (iter = attach_list; iter != NULL; iter = iter->next) {
-		EAttachment *attachment;
-		const gchar *uri = iter->data;
+	/* XXX What an awkward API this is.  Takes a return location
+	 *     for a constant string instead of just returning it. */
+	e_cal_component_get_uid (editor->priv->comp, &uid);
 
-		attachment = e_attachment_new_for_uri (uri);
+	for (iter = uri_list; iter != NULL; iter = iter->next) {
+		EAttachment *attachment;
+
+		attachment = e_attachment_new_for_uri (iter->data);
 		e_attachment_store_add_attachment (store, attachment);
+		g_object_set_data_full (
+			G_OBJECT (attachment),
+			"uid", g_strdup (uid),
+			(GDestroyNotify) g_free);
 		e_attachment_load_async (
 			attachment, (GAsyncReadyCallback)
-			e_attachment_load_handle_error, editor);
+			attachment_loaded_cb, editor);
 		g_object_unref (attachment);
 	}
 }
@@ -2324,9 +2379,9 @@ real_edit_comp (CompEditor *editor, ECalComponent *comp)
 	if (comp)
 		priv->comp = e_cal_component_clone (comp);
 
- 	priv->existing_org = e_cal_component_has_organizer (comp);
- 	priv->user_org = (itip_organizer_is_user (comp, priv->client) || itip_sentby_is_user (comp, priv->client));
- 	priv->warned = FALSE;
+	priv->existing_org = e_cal_component_has_organizer (comp);
+	priv->user_org = (itip_organizer_is_user (comp, priv->client) || itip_sentby_is_user (comp, priv->client));
+	priv->warned = FALSE;
 
 	update_window_border (editor, NULL);
 
@@ -2339,7 +2394,7 @@ real_edit_comp (CompEditor *editor, ECalComponent *comp)
 
 /* TODO These functions should be available in e-cal-component.c */
 static void
-set_attendees_for_delegation (ECalComponent *comp, const char *address, ECalComponentItipMethod method)
+set_attendees_for_delegation (ECalComponent *comp, const gchar *address, ECalComponentItipMethod method)
 {
 	icalproperty *prop;
 	icalparameter *param;
@@ -2350,8 +2405,8 @@ set_attendees_for_delegation (ECalComponent *comp, const char *address, ECalComp
 	for (prop = icalcomponent_get_first_property (icalcomp, ICAL_ATTENDEE_PROPERTY);
 			prop;
 			prop = icalcomponent_get_next_property (icalcomp, ICAL_ATTENDEE_PROPERTY)) {
-		const char *attendee = icalproperty_get_attendee (prop);
-		const char *delfrom = NULL;
+		const gchar *attendee = icalproperty_get_attendee (prop);
+		const gchar *delfrom = NULL;
 
 		param = icalproperty_get_first_parameter(prop, ICAL_DELEGATEDFROM_PARAMETER);
 		if (param)
@@ -2371,8 +2426,8 @@ get_users_from_memo_comp (ECalComponent *comp, GList **users)
 {
 	icalcomponent *icalcomp;
 	icalproperty *icalprop;
-	const char *attendees = NULL;
-	char **emails, **iter;
+	const gchar *attendees = NULL;
+	gchar **emails, **iter;
 
 	icalcomp = e_cal_component_get_icalcomponent (comp);
 
@@ -2402,7 +2457,7 @@ real_send_comp (CompEditor *editor, ECalComponentItipMethod method, gboolean str
 	CompEditorPrivate *priv;
 	CompEditorFlags flags;
 	ECalComponent *send_comp = NULL;
-	char *address = NULL;
+	gchar *address = NULL;
 	GList *users = NULL;
 
 	g_return_val_if_fail (IS_COMP_EDITOR (editor), FALSE);
@@ -2413,7 +2468,7 @@ real_send_comp (CompEditor *editor, ECalComponentItipMethod method, gboolean str
 	if (priv->mod == CALOBJ_MOD_ALL && e_cal_component_is_instance (priv->comp)) {
 		/* Ensure we send the master object, not the instance only */
 		icalcomponent *icalcomp = NULL;
-		const char *uid = NULL;
+		const gchar *uid = NULL;
 
 		e_cal_component_get_uid (priv->comp, &uid);
 		if (e_cal_get_object (priv->client, uid, NULL, &icalcomp, NULL) && icalcomp) {
@@ -2440,7 +2495,7 @@ real_send_comp (CompEditor *editor, ECalComponentItipMethod method, gboolean str
 			set_attendees_for_delegation (send_comp, address, method);
 	}
 
-	if (!e_cal_component_has_attachments (priv->comp) 
+	if (!e_cal_component_has_attachments (priv->comp)
 	  || e_cal_get_static_capability (priv->client, CAL_STATIC_CAPABILITY_CREATE_MESSAGES)) {
 		if (itip_send_comp (method, send_comp, priv->client,
 					NULL, NULL, users, strip_alarms)) {
@@ -2449,13 +2504,13 @@ real_send_comp (CompEditor *editor, ECalComponentItipMethod method, gboolean str
 		}
 	} else {
 		/* Clone the component with attachments set to CID:...  */
-		int num_attachments, i;
+		gint num_attachments, i;
 		GSList *attach_list = NULL;
 		GSList *mime_attach_list;
 
 		num_attachments = e_cal_component_get_num_attachments (send_comp);
 
-		for (i = 0; i < num_attachments ; i++) {
+		for (i = 0; i < num_attachments; i++) {
 			attach_list = g_slist_append (attach_list, g_strdup ("CID:..."));
 		}
 		e_cal_component_set_attachment_list (send_comp, attach_list);
@@ -2483,7 +2538,6 @@ real_send_comp (CompEditor *editor, ECalComponentItipMethod method, gboolean str
 
 }
 
-
 /**
  * comp_editor_edit_comp:
  * @editor: A component editor
@@ -2567,7 +2621,7 @@ void
 comp_editor_delete_comp (CompEditor *editor)
 {
 	CompEditorPrivate *priv;
-	const char *uid;
+	const gchar *uid;
 
 	g_return_if_fail (IS_COMP_EDITOR (editor));
 
@@ -2620,7 +2674,6 @@ comp_editor_close (CompEditor *editor)
 	return close;
 }
 
-
 /* Utility function to get the mime-attachment list from the attachment
  * bar for sending the comp via itip. The list and its contents must
  * be freed by the caller.
@@ -2647,8 +2700,8 @@ comp_editor_get_mime_attach_list (CompEditor *editor)
 		CamelDataWrapper *wrapper;
 		CamelMimePart *mime_part;
 		CamelStreamMem *mstream;
-		unsigned char *buffer = NULL;
-		const char *desc, *disp;
+		guchar *buffer = NULL;
+		const gchar *desc, *disp;
 		gint column_id;
 
 		column_id = E_ATTACHMENT_STORE_COLUMN_ATTACHMENT;
@@ -2668,7 +2721,7 @@ comp_editor_get_mime_attach_list (CompEditor *editor)
 		camel_data_wrapper_decode_to_stream (wrapper, (CamelStream *) mstream);
 		buffer = g_memdup (mstream->buffer->data, mstream->buffer->len);
 
-		cal_mime_attach->encoded_data = (char *)buffer;
+		cal_mime_attach->encoded_data = (gchar *)buffer;
 		cal_mime_attach->length = mstream->buffer->len;
 		cal_mime_attach->filename = g_strdup (camel_mime_part_get_filename (mime_part));
 		desc = camel_mime_part_get_description (mime_part);
