@@ -13,7 +13,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
@@ -21,7 +21,7 @@
  */
 
 #include "e-composer-header.h"
-
+#include <glib/gi18n.h>
 #define E_COMPOSER_HEADER_GET_PRIVATE(obj) \
 	(G_TYPE_INSTANCE_GET_PRIVATE \
 	((obj), E_TYPE_COMPOSER_HEADER, EComposerHeaderPrivate))
@@ -47,6 +47,7 @@ struct _EComposerHeaderPrivate {
 	gboolean button;
 	gchar *addaction_text;
 	gboolean addaction; /*For Add button.*/
+	GtkWidget *action_label;
 
 	guint sensitive : 1;
 	guint visible   : 1;
@@ -67,14 +68,9 @@ static void
 composer_header_addaction_clicked_cb (GtkButton *button,
 				      EComposerHeader *header)
 {
-	gtk_widget_hide ((GtkWidget *)button);
-	e_composer_header_set_visible (header, TRUE);
-}
+	gboolean show = !e_composer_header_get_visible(header);
 
-static void                
-link_clicked_cb (GtkLinkButton *button, const gchar *link_, gpointer user_data)
-{
-	return;
+	e_composer_header_set_visible (header, show);
 }
 
 static GObject *
@@ -105,17 +101,23 @@ composer_header_constructor (GType type,
 			GTK_LABEL (widget), header->input_widget);
 	}
 
+	header->priv->action_label = NULL;
 	if (header->priv->addaction) {
 		GtkWidget *box, *tmp;
-		char *str;
+		gchar *str;
 
 		header->action_widget = gtk_button_new ();
 		box = gtk_hbox_new (FALSE, 0);
 		tmp = gtk_image_new_from_stock("gtk-add", GTK_ICON_SIZE_BUTTON);
 		gtk_box_pack_start((GtkBox *)box, tmp, FALSE, FALSE, 3);
 		tmp = gtk_label_new (NULL);
-		str = g_strdup_printf ("<span foreground='blue' underline='single' underline_color='blue'  >%s</span>", header->priv->addaction_text);
+		str = g_strdup_printf ("<span foreground='blue' underline='single' underline_color='blue'  >%s %s</span>", _("Show"), header->priv->addaction_text);
+		g_object_set_data ((GObject *)tmp, "show", str);
 		gtk_label_set_markup((GtkLabel *)tmp, str);
+		str = g_strdup_printf ("<span foreground='blue' underline='single' underline_color='blue'  >%s %s</span>", _("Hide"), header->priv->addaction_text);
+		g_object_set_data ((GObject *)tmp, "hide", str);
+
+		header->priv->action_label = tmp;
 		gtk_box_pack_start((GtkBox *)box, tmp, FALSE, FALSE, 3);
 		gtk_container_add((GtkContainer *)header->action_widget, box);
 		gtk_widget_show_all(header->action_widget);
@@ -426,6 +428,12 @@ e_composer_header_set_visible (EComposerHeader *header,
 
 	header->priv->visible = visible;
 
+	if (header->priv->action_label) {
+		if (!visible)
+			gtk_label_set_markup ((GtkLabel *)header->priv->action_label, g_object_get_data ((GObject *)header->priv->action_label, "show"));
+		else
+			gtk_label_set_markup ((GtkLabel *)header->priv->action_label, g_object_get_data ((GObject *)header->priv->action_label, "hide"));
+	}
 	g_object_notify (G_OBJECT (header), "visible");
 }
 
