@@ -11,20 +11,28 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <unistd.h>
 #include <sys/types.h>
-#include <sys/wait.h>
+#ifdef HAVE_SYS_WAIT_H
+#  include <sys/wait.h>
+#endif
+#include <stdlib.h>
 #include <gtk/gtk.h>
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
-#include <libgnomeui/libgnomeui.h>
+#include <libgnomeui/gnome-druid.h>
+#include <libgnomeui/gnome-druid-page-standard.h>
 #include "shell/es-menu.h"
 #include "mail/em-config.h"
 #include "mail/em-account-editor.h"
@@ -40,48 +48,52 @@ void backup_restore_abort (EPlugin *ep, EMConfigTargetAccount *target);
 
 typedef enum _br_flags {
 	BR_OK = 1<<0,
-	BR_START = 1<<1,
+	BR_START = 1<<1
 }br_flags;
 
 static void
-backup (const char *filename, gboolean restart)
+backup (const gchar *filename, gboolean restart)
 {
 	if (restart)
-		 execl (EVOLUTION_TOOLSDIR "/evolution-backup", "evolution-backup", "--gui", "--backup", "--restart", filename, NULL);
+		execl (EVOLUTION_TOOLSDIR "/evolution-backup", "evolution-backup", "--gui", "--backup", "--restart", filename, (gchar *)NULL);
 	else
-		 execl (EVOLUTION_TOOLSDIR "/evolution-backup", "evolution-backup", "--gui", "--backup", filename, NULL);
+		execl (EVOLUTION_TOOLSDIR "/evolution-backup", "evolution-backup", "--gui", "--backup", filename, (gchar *)NULL);
 }
 
 static void
-restore (const char *filename, gboolean restart)
+restore (const gchar *filename, gboolean restart)
 {
 	if (restart)
-		 execl (EVOLUTION_TOOLSDIR "/evolution-backup", "evolution-backup", "--gui", "--restore", "--restart", filename, NULL);
+		execl (EVOLUTION_TOOLSDIR "/evolution-backup", "evolution-backup", "--gui", "--restore", "--restart", filename, (gchar *)NULL);
 	else
-		 execl (EVOLUTION_TOOLSDIR "/evolution-backup", "evolution-backup", "--gui", "--restore", filename, NULL);
+		execl (EVOLUTION_TOOLSDIR "/evolution-backup", "evolution-backup", "--gui", "--restore", filename, (gchar *)NULL);
 }
 
 static gboolean
-sanity_check (const char *filename)
+sanity_check (const gchar *filename)
 {
-	char *command;
-	int result;
+	gchar *command;
+	gint result;
 
 	command = g_strdup_printf ("%s/evolution-backup --check %s", EVOLUTION_TOOLSDIR, filename);
 	result = system (command);
 	g_free (command);
 
+#ifdef HAVE_SYS_WAIT_H
 	g_message ("Sanity check result %d:%d %d", WIFEXITED (result), WEXITSTATUS (result), result);
 
 	return WIFEXITED (result) && (WEXITSTATUS (result) == 0);
+#else
+	return result;
+#endif
 }
 
 static guint32
-dialog_prompt_user(GtkWindow *parent, const char *string, const char *tag, const char *arg0, ...)
+dialog_prompt_user(GtkWindow *parent, const gchar *string, const gchar *tag, const gchar *arg0, ...)
 {
 	GtkWidget *mbox, *check = NULL;
 	va_list ap;
-	int button;
+	gint button;
 	guint32 mask = 0;
 
 	va_start(ap, arg0);
@@ -108,12 +120,12 @@ dialog_prompt_user(GtkWindow *parent, const char *string, const char *tag, const
 }
 
 static gboolean
-epbr_perform_pre_backup_checks (char* dir)
+epbr_perform_pre_backup_checks (gchar * dir)
 {
 #ifdef G_OS_WIN32
 	return TRUE;
 #else
-	return (g_access (dir, W_OK) == 0); 
+	return (g_access (dir, W_OK) == 0);
 #endif
 }
 
@@ -122,14 +134,14 @@ org_gnome_backup_restore_backup (EPlugin *ep, ESMenuTargetShell *target)
 {
 	GtkWidget *dlg;
 	GtkWidget *vbox;
-	int response;
+	gint response;
 
 	dlg = e_file_get_save_filesel(target->target.widget, _("Select name of the Evolution backup file"), NULL, GTK_FILE_CHOOSER_ACTION_SAVE);
 
-/* 	dlg = gtk_file_chooser_dialog_new (_("Select name of the Evolution backup file"), GTK_WINDOW (target->target.widget),  */
-/* 					   GTK_FILE_CHOOSER_ACTION_SAVE,  */
-/* 					   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,  */
-/* 					   GTK_STOCK_SAVE, GTK_RESPONSE_OK, NULL); */
+/*	dlg = gtk_file_chooser_dialog_new (_("Select name of the Evolution backup file"), GTK_WINDOW (target->target.widget),  */
+/*					   GTK_FILE_CHOOSER_ACTION_SAVE,  */
+/*					   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,  */
+/*					   GTK_STOCK_SAVE, GTK_RESPONSE_OK, NULL); */
 
 	gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dlg), "evolution-backup.tar.gz");
 
@@ -138,10 +150,10 @@ org_gnome_backup_restore_backup (EPlugin *ep, ESMenuTargetShell *target)
 
 	response = gtk_dialog_run (GTK_DIALOG (dlg));
 	if (response == GTK_RESPONSE_OK) {
-		char *filename;
+		gchar *filename;
 		guint32 mask;
-		char *uri = NULL;
-		char *dir;
+		gchar *uri = NULL;
+		gchar *dir;
 
 		uri = gtk_file_chooser_get_current_folder_uri(GTK_FILE_CHOOSER (dlg));
 		e_file_update_save_path(uri, TRUE);
@@ -150,7 +162,6 @@ org_gnome_backup_restore_backup (EPlugin *ep, ESMenuTargetShell *target)
 		dir = gtk_file_chooser_get_current_folder (GTK_FILE_CHOOSER (dlg));
 		gtk_widget_destroy (dlg);
 
-
 		if (epbr_perform_pre_backup_checks (dir)) {
 
 			mask = dialog_prompt_user (GTK_WINDOW (target->target.widget), _("_Restart Evolution after backup"), "org.gnome.backup-restore:backup-confirm", NULL);
@@ -174,22 +185,22 @@ org_gnome_backup_restore_restore (EPlugin *ep, ESMenuTargetShell *target)
 {
 	GtkWidget *dlg;
 	GtkWidget *vbox;
-	int response;
+	gint response;
 
 	dlg = e_file_get_save_filesel(target->target.widget, _("Select name of the Evolution backup file to restore"), NULL, GTK_FILE_CHOOSER_ACTION_OPEN);
 
-/* 	dlg = gtk_file_chooser_dialog_new (_("Select Evolution backup file to restore"), GTK_WINDOW (target->target.widget),  */
-/* 					   GTK_FILE_CHOOSER_ACTION_OPEN,  */
-/* 					   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,  */
-/* 					   GTK_STOCK_OPEN, GTK_RESPONSE_OK, NULL); */
+/*	dlg = gtk_file_chooser_dialog_new (_("Select Evolution backup file to restore"), GTK_WINDOW (target->target.widget),  */
+/*					   GTK_FILE_CHOOSER_ACTION_OPEN,  */
+/*					   GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,  */
+/*					   GTK_STOCK_OPEN, GTK_RESPONSE_OK, NULL); */
 
 	vbox = gtk_vbox_new (FALSE, 6);
 	gtk_widget_show (vbox);
 
 	response = gtk_dialog_run (GTK_DIALOG (dlg));
 	if (response == GTK_RESPONSE_OK) {
-		char *filename;
-		char *uri = NULL;
+		gchar *filename;
+		gchar *uri = NULL;
 
 		uri = gtk_file_chooser_get_current_folder_uri(GTK_FILE_CHOOSER (dlg));
 		e_file_update_save_path(uri, TRUE);
@@ -220,7 +231,7 @@ check_toggled (GtkToggleButton *button, GnomeDruid *druid)
 {
 	 GtkWidget *box = g_object_get_data ((GObject *)button, "box");
 	gboolean state =  gtk_toggle_button_get_active ((GtkToggleButton *)button);
-	char *prevfile = g_object_get_data ((GObject *)druid, "restore-file");
+	gchar *prevfile = g_object_get_data ((GObject *)druid, "restore-file");
 
 	gtk_widget_set_sensitive (box, state);
 	gnome_druid_set_show_finish (druid, state);
@@ -237,7 +248,7 @@ static void
 restore_wizard (GnomeDruidPage *druidpage, GnomeDruid *druid, gpointer user_data)
 {
 	gboolean state = GPOINTER_TO_INT(g_object_get_data((GObject *)druid, "restore")) ? TRUE:FALSE;
-	char *file = g_object_get_data ((GObject *)druid, "restore-file");
+	gchar *file = g_object_get_data ((GObject *)druid, "restore-file");
 
 	if (state) {
 		if (!file ||!sanity_check (file)) {
@@ -251,8 +262,8 @@ restore_wizard (GnomeDruidPage *druidpage, GnomeDruid *druid, gpointer user_data
 static void
 file_changed (GtkFileChooser *chooser, GnomeDruid *druid)
 {
-	char *file = NULL, *prevfile=NULL;
-	char *uri = NULL;
+	gchar *file = NULL, *prevfile=NULL;
+	gchar *uri = NULL;
 
 	uri = gtk_file_chooser_get_current_folder_uri(GTK_FILE_CHOOSER (chooser));
 	e_file_update_save_path(uri, TRUE);
@@ -298,7 +309,6 @@ backup_restore_page (EPlugin *ep, EConfigHookItemFactoryData *hook_data)
 	gtk_box_pack_start ((GtkBox *)box, hbox, FALSE, FALSE, 0);
 	gtk_widget_set_sensitive (hbox, FALSE);
 
-
 	gtk_container_add ((GtkContainer *) GNOME_DRUID_PAGE_STANDARD (page)->vbox, box);
 	gtk_widget_show_all (box);
 	gnome_druid_append_page (GNOME_DRUID (hook_data->parent), GNOME_DRUID_PAGE (page));
