@@ -8,31 +8,27 @@
  *  This works today (25 October 2004), but is pretty sure to break
  *  later on as the Gaim buddylist file format shifts.
  *
- *  Nat Friedman <nat@novell.com>
+ * This program is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
- *  Copyright 2004 Novell, Inc.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Nat Friedman <nat@novell.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- *  Permission is hereby granted, free of charge, to any person
- *  obtaining a copy of this software and associated documentation
- *  files (the "Software"), to deal in the Software without
- *  restriction, including without limitation the rights to use, copy,
- *  modify, merge, publish, distribute, sublicense, and/or sell copies
- *  of the Software, and to permit persons to whom the Software is
- *  furnished to do so, subject to the following conditions:
- *  
- *  The above copyright notice and this permission notice shall be
- *  included in all copies or substantial portions of the Software.
- *  
- *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
- *  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
- *  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
- *  NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
- *  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
- *  WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
- *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
- *  DEALINGS IN THE SOFTWARE.
  */
- 
+
 #include <glib.h>
 #include <libxml/tree.h>
 #include <libxml/parser.h>
@@ -44,7 +40,7 @@
 #include <string.h>
 
 #include <libebook/e-book.h>
-#include <libedataserverui/e-source-option-menu.h>
+#include <libedataserverui/e-source-combo-box.h>
 
 #include <sys/time.h>
 #include <sys/stat.h>
@@ -54,25 +50,20 @@
 #include "bbdb.h"
 
 typedef struct {
-	char *account_name;
-	char *proto;
-	char *alias;
-	char *icon;
+	gchar *account_name;
+	gchar *proto;
+	gchar *alias;
+	gchar *icon;
 } GaimBuddy;
 
-/* Defined in bbdb.c */
-EBook *bbdb_open_addressbook (int type);
-
 /* Forward declarations for this file. */
-void bbdb_sync_buddy_list (void);
 static gboolean bbdb_merge_buddy_to_contact (EBook *book, GaimBuddy *b, EContact *c);
 static GList *bbdb_get_gaim_buddy_list (void);
-static char *get_node_text (xmlNodePtr node);
-static char *get_buddy_icon_from_setting (xmlNodePtr setting);
-static char *get_node_text (xmlNodePtr node);
+static gchar *get_node_text (xmlNodePtr node);
+static gchar *get_buddy_icon_from_setting (xmlNodePtr setting);
 static void free_buddy_list (GList *blist);
-static void parse_buddy_group (xmlNodePtr group, GList **buddies);
-static EContactField proto_to_contact_field (const char *proto);
+static void parse_buddy_group (xmlNodePtr group, GList **buddies, GSList *blocked);
+static EContactField proto_to_contact_field (const gchar *proto);
 
 void
 bbdb_sync_buddy_list_check (void)
@@ -80,11 +71,11 @@ bbdb_sync_buddy_list_check (void)
 	GConfClient *gconf;
 	struct stat statbuf;
 	time_t last_sync;
-	char *blist_path;
-	char *last_sync_str;
+	gchar *blist_path;
+	gchar *last_sync_str;
 
 	gconf = gconf_client_get_default ();
-	
+
 	blist_path = g_build_path ("/", getenv ("HOME"), ".purple/blist.xml", NULL);
 	if (stat (blist_path, &statbuf) < 0) {
 		g_free (blist_path);
@@ -96,7 +87,7 @@ bbdb_sync_buddy_list_check (void)
 
 	/* Reprocess the buddy list if it's been updated. */
 	last_sync_str = gconf_client_get_string (gconf, GCONF_KEY_GAIM_LAST_SYNC, NULL);
-	if (last_sync_str == NULL || ! strcmp ((const char *)last_sync_str, ""))
+	if (last_sync_str == NULL || ! strcmp ((const gchar *)last_sync_str, ""))
 		last_sync = (time_t) 0;
 	else
 		last_sync = (time_t) g_ascii_strtoull (last_sync_str, NULL, 10);
@@ -151,7 +142,7 @@ bbdb_sync_buddy_list (void)
 			   name, just give up; we're not smart enough for
 			   this. */
 			if (contacts->next != NULL)
- 				continue;
+				continue;
 
 			c = E_CONTACT (contacts->data);
 
@@ -173,22 +164,21 @@ bbdb_sync_buddy_list (void)
 			g_object_unref (G_OBJECT (c));
 			continue;
 		}
-		
+
 		if (! e_book_add_contact (book, c, &error)) {
 			g_warning ("bbdb: Failed to add new contact: %s\n", error->message);
 			g_error_free (error);
 			return;
 		}
 		g_object_unref (G_OBJECT (c));
-		
-	}
 
+	}
 
 	/* Update the last-sync'd time */
 	{
 		GConfClient *gconf;
 		time_t  last_sync;
-		char   *last_sync_str;
+		gchar   *last_sync_str;
 
 		gconf = gconf_client_get_default ();
 
@@ -208,7 +198,7 @@ im_list_contains_buddy (GList *ims, GaimBuddy *b)
 	GList *l;
 
 	for (l = ims; l != NULL; l = l->next) {
-		char *im = (char *) l->data;
+		gchar *im = (gchar *) l->data;
 
 		if (! strcmp (im, b->account_name))
 			return TRUE;
@@ -241,19 +231,21 @@ bbdb_merge_buddy_to_contact (EBook *book, GaimBuddy *b, EContact *c)
 	if (b->icon != NULL) {
 		photo = e_contact_get (c, E_CONTACT_PHOTO);
 		if (photo == NULL) {
+			gchar *contents = NULL;
 
 			photo = g_new0 (EContactPhoto, 1);
 			photo->type = E_CONTACT_PHOTO_TYPE_INLINED;
 
-			if (! g_file_get_contents (b->icon, (gchar **) &photo->data.inlined.data, &photo->data.inlined.length, &error)) {
+			if (! g_file_get_contents (b->icon, &contents, &photo->data.inlined.length, &error)) {
 				g_warning ("bbdb: Could not read buddy icon: %s\n", error->message);
 				g_error_free (error);
 				for (l = ims; l != NULL; l = l->next)
-					g_free ((char *) l->data);
+					g_free ((gchar *) l->data);
 				g_list_free (ims);
 				return dirty;
 			}
 
+			photo->data.inlined.data = (guchar *)contents;
 			e_contact_set (c, E_CONTACT_PHOTO, (gpointer) photo);
 			dirty = TRUE;
 		}
@@ -264,14 +256,14 @@ bbdb_merge_buddy_to_contact (EBook *book, GaimBuddy *b, EContact *c)
 		e_contact_photo_free (photo);
 
 	for (l = ims; l != NULL; l = l->next)
-		g_free ((char *) l->data);
+		g_free ((gchar *) l->data);
 	g_list_free (ims);
 
 	return dirty;
 }
 
 static EContactField
-proto_to_contact_field (const char *proto)
+proto_to_contact_field (const gchar *proto)
 {
 	if (! strcmp (proto,  "prpl-oscar"))
 		return E_CONTACT_IM_AIM;
@@ -291,13 +283,35 @@ proto_to_contact_field (const char *proto)
 	return E_CONTACT_IM_AIM;
 }
 
+static void
+get_all_blocked (xmlNodePtr node, GSList **blocked)
+{
+	xmlNodePtr child;
+
+	if (!node || !blocked)
+		return;
+
+	for (child = node->children; child; child = child->next) {
+		if (child->children)
+			get_all_blocked (child, blocked);
+
+		if (!strcmp ((const gchar *)child->name, "block")) {
+			gchar *name = get_node_text (child);
+
+			if (name)
+				*blocked = g_slist_prepend (*blocked, name);
+		}
+	}
+}
+
 static GList *
 bbdb_get_gaim_buddy_list (void)
 {
-	char *blist_path;
+	gchar *blist_path;
 	xmlDocPtr buddy_xml;
 	xmlNodePtr root, child, blist;
 	GList *buddies = NULL;
+	GSList *blocked = NULL;
 
 	blist_path = g_build_path ("/", getenv ("HOME"), ".purple/blist.xml", NULL);
 
@@ -309,15 +323,22 @@ bbdb_get_gaim_buddy_list (void)
 	}
 
 	root = xmlDocGetRootElement (buddy_xml);
-	if (strcmp ((const char *)root->name, "purple")) {
+	if (strcmp ((const gchar *)root->name, "purple")) {
 		fprintf (stderr, "bbdb: Could not parse Pidgin buddy list.\n");
 		xmlFreeDoc (buddy_xml);
 		return NULL;
 	}
 
+	for (child = root->children; child != NULL; child = child->next) {
+		if (! strcmp ((const gchar *)child->name, "privacy")) {
+			get_all_blocked (child, &blocked);
+			break;
+		}
+	}
+
 	blist = NULL;
 	for (child = root->children; child != NULL; child = child->next) {
-		if (! strcmp ((const char *)child->name, "blist")) {
+		if (! strcmp ((const gchar *)child->name, "blist")) {
 			blist = child;
 			break;
 		}
@@ -329,70 +350,75 @@ bbdb_get_gaim_buddy_list (void)
 	}
 
 	for (child = blist->children; child != NULL; child = child->next) {
-		if (! strcmp ((const char *)child->name, "group"))
-			parse_buddy_group (child, &buddies);
+		if (! strcmp ((const gchar *)child->name, "group"))
+			parse_buddy_group (child, &buddies, blocked);
 	}
 
 	xmlFreeDoc (buddy_xml);
 
+	g_slist_foreach (blocked, (GFunc)g_free, NULL);
+	g_slist_free (blocked);
+
 	return buddies;
 }
 
 static void
-free_buddy_list (GList *blist)
+free_gaim_body (GaimBuddy *gb)
 {
-	GList *l;
+	if (!gb)
+		return;
 
-	for (l = blist; l != NULL; l = l->next) {
-		GaimBuddy *gb = l->data;
-
-		g_free (gb->icon);
-		g_free (gb->alias);
-		g_free (gb->account_name);
-		g_free (gb->proto);
-		g_free (gb);
-	}
-
-	g_list_free (l);
+	g_free (gb->icon);
+	g_free (gb->alias);
+	g_free (gb->account_name);
+	g_free (gb->proto);
+	g_free (gb);
 }
 
-static char *
+static void
+free_buddy_list (GList *blist)
+{
+	g_list_foreach (blist, (GFunc)free_gaim_body, NULL);
+	g_list_free (blist);
+}
+
+static gchar *
 get_node_text (xmlNodePtr node)
 {
 	if (node->children == NULL || node->children->content == NULL ||
-	    strcmp ((char *)node->children->name, "text"))
+	    strcmp ((gchar *)node->children->name, "text"))
 		return NULL;
 
-	return g_strdup ((char *)node->children->content);
+	return g_strdup ((gchar *)node->children->content);
 }
 
-static char *
+static gchar *
 get_buddy_icon_from_setting (xmlNodePtr setting)
 {
-	char *icon = NULL;
+	gchar *icon = NULL;
 
 	icon = get_node_text (setting);
 	if (icon [0] != '/') {
-		char *path;
+		gchar *path;
 
 		path = g_build_path ("/", getenv ("HOME"), ".purple/icons", icon, NULL);
 		g_free (icon);
 		icon = path;
 	}
 
-
 	return icon;
 }
 
 static void
-parse_contact (xmlNodePtr contact, GList **buddies)
+parse_contact (xmlNodePtr contact, GList **buddies, GSList *blocked)
 {
 	xmlNodePtr  child;
 	xmlNodePtr  buddy = NULL;
 	GaimBuddy  *gb;
+	gboolean    is_blocked = FALSE;
 
 	for (child = contact->children; child != NULL; child = child->next) {
-		if (! strcmp ((const char *)child->name, "buddy")) {
+		if (! strcmp ((const gchar *)child->name, "buddy")) {
 			buddy = child;
 			break;
 		}
@@ -405,36 +431,40 @@ parse_contact (xmlNodePtr contact, GList **buddies)
 
 	gb = g_new0 (GaimBuddy, 1);
 
-	gb->proto = e_xml_get_string_prop_by_name (buddy, (const unsigned char *)"proto");
+	gb->proto = e_xml_get_string_prop_by_name (buddy, (const guchar *)"proto");
 
-	for (child = buddy->children; child != NULL; child = child->next) {
-		if (! strcmp ((const char *)child->name, "setting")) {
-			char *setting_type;
-			setting_type = e_xml_get_string_prop_by_name (child, (const unsigned char *)"name");
+	for (child = buddy->children; child != NULL && !is_blocked; child = child->next) {
+		if (! strcmp ((const gchar *)child->name, "setting")) {
+			gchar *setting_type;
+			setting_type = e_xml_get_string_prop_by_name (child, (const guchar *)"name");
 
-			if (! strcmp ((const char *)setting_type, "buddy_icon"))
+			if (! strcmp ((const gchar *)setting_type, "buddy_icon"))
 				gb->icon = get_buddy_icon_from_setting (child);
 
 			g_free (setting_type);
-		} else if (! strcmp ((const char *)child->name, "name"))
+		} else if (! strcmp ((const gchar *)child->name, "name")) {
 			gb->account_name = get_node_text (child);
-		else if (! strcmp ((const char *)child->name, "alias"))
+			is_blocked = g_slist_find_custom (blocked, gb->account_name, (GCompareFunc)strcmp) != NULL;
+		} else if (! strcmp ((const gchar *)child->name, "alias"))
 			gb->alias = get_node_text (child);
-			
+
 	}
 
-	*buddies = g_list_prepend (*buddies, gb);
+	if (is_blocked)
+		free_gaim_body (gb);
+	else
+		*buddies = g_list_prepend (*buddies, gb);
 }
 
 static void
-parse_buddy_group (xmlNodePtr group, GList **buddies)
+parse_buddy_group (xmlNodePtr group, GList **buddies, GSList *blocked)
 {
 	xmlNodePtr child;
 
 	for (child = group->children; child != NULL; child = child->next) {
-		if (strcmp ((const char *)child->name, "contact"))
+		if (strcmp ((const gchar *)child->name, "contact"))
 			continue;
 
-		parse_contact (child, buddies);
+		parse_contact (child, buddies, blocked);
 	}
 }
