@@ -1,23 +1,25 @@
 /*
- * Copyright (C) 2005 Novell, Inc.
- *
- * Author(s): Vivek Jain <jvivek@novell.com>
- *
  * This program is free software; you can redistribute it and/or
- * modify it under the terms of version 2 of the GNU General Public
- * License as published by the Free Software Foundation.
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) version 3.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
+ *
+ *
+ * Authors:
+ *		Vivek Jain <jvivek@novell.com>
+ *
+ * Copyright (C) 1999-2008 Novell, Inc. (www.novell.com)
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
-
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -46,11 +48,11 @@ org_gnome_junk_settings(EPlugin *ep, EMPopupTargetSelect *t);
 static void
 abort_changes (JunkSettings *js)
 {
-       	g_object_run_dispose ((GObject *)js);
+	g_object_run_dispose ((GObject *)js);
 }
 
 static void
-junk_dialog_response (GtkWidget *dialog, int response, JunkSettings *js)
+junk_dialog_response (GtkWidget *dialog, gint response, JunkSettings *js)
 {
 	if (response == GTK_RESPONSE_ACCEPT) {
 		commit_changes(js);
@@ -64,11 +66,11 @@ junk_dialog_response (GtkWidget *dialog, int response, JunkSettings *js)
 }
 
 static void
-junk_mail_settings (EPopup *ep, EPopupItem *item, void *data)
+junk_mail_settings (EPopup *ep, EPopupItem *item, gpointer data)
 {
 	GtkWidget *dialog ,*w, *notebook, *box;
 	JunkSettings *junk_tab;
-	int page_count =0;
+	gint page_count =0;
 	EGwConnection *cnc;
 	gchar *msg;
 	CamelFolder *folder = (CamelFolder *)data;
@@ -112,11 +114,11 @@ junk_mail_settings (EPopup *ep, EPopupItem *item, void *data)
 }
 
 static EPopupItem popup_items[] = {
-{ E_POPUP_ITEM, "50.emfv.05", N_("Junk Mail Settings..."), junk_mail_settings, NULL, NULL, 0, EM_POPUP_SELECT_MANY|EM_FOLDER_VIEW_SELECT_LISTONLY}
+	{ E_POPUP_ITEM, (gchar *) "50.emfv.05", (gchar *) N_("Junk Mail Settings..."), junk_mail_settings, NULL, NULL, 0, EM_POPUP_SELECT_MANY|EM_FOLDER_VIEW_SELECT_LISTONLY}
 };
 
 static void
-popup_free (EPopup *ep, GSList *items, void *data)
+popup_free (EPopup *ep, GSList *items, gpointer data)
 {
 g_slist_free (items);
 }
@@ -126,11 +128,11 @@ org_gnome_junk_settings(EPlugin *ep, EMPopupTargetSelect *t)
 {
 	GSList *menus = NULL;
 
-	int i = 0;
-	static int first = 0;
+	gint i = 0;
+	static gint first = 0;
 
 	if (! g_strrstr (t->uri, "groupwise://"))
-		return ;
+		return;
 
 	/* for translation*/
 	if (!first) {
