@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -30,11 +30,10 @@
 #include <bonobo/bonobo-shlib-factory.h>
 #include <bonobo/bonobo-control.h>
 #include <bonobo/bonobo-exception.h>
-#include <gtk/gtklabel.h>
+#include <gtk/gtk.h>
 #include "e-task-bar.h"
 #include "evolution-test-component.h"
 
-
 #define FACTORY_ID "OAFIID:GNOME_Evolution_Test_Factory:" BASE_VERSION
 #define TEST_COMPONENT_ID  "OAFIID:GNOME_Evolution_Test_Component:" BASE_VERSION
 #define CREATE_TEST_ID      "test"
@@ -88,7 +87,6 @@ impl_upgradeFromVersion (PortableServer_Servant servant,
 	g_message ("Upgrading from %d.%d.%d", major, minor, revision);
 }
 
-
 static GNOME_Evolution_CreatableItemTypeList *
 impl__get_userCreatableItems (PortableServer_Servant servant,
 			      CORBA_Environment *ev)
@@ -103,7 +101,7 @@ impl__get_userCreatableItems (PortableServer_Servant servant,
 
 	list->_buffer[0].id = CREATE_TEST_ID;
 	list->_buffer[0].description = _("New Test");
-	list->_buffer[0].menuDescription = (char *) C_("New", "_Test");
+	list->_buffer[0].menuDescription = (gchar *) C_("New", "_Test");
 	list->_buffer[0].tooltip = _("Create a new test item");
 	list->_buffer[0].menuShortcut = 'i';
 	list->_buffer[0].iconName = "";
@@ -161,8 +159,8 @@ BONOBO_TYPE_FUNC_FULL (EvolutionTestComponent, GNOME_Evolution_Component, PARENT
 
 static BonoboObject *
 factory (BonoboGenericFactory *factory,
-	 const char *component_id,
-	 void *closure)
+	 const gchar *component_id,
+	 gpointer closure)
 {
 	if (strcmp (component_id, TEST_COMPONENT_ID) == 0) {
 		BonoboObject *object = BONOBO_OBJECT (g_object_new (EVOLUTION_TEST_TYPE_COMPONENT, NULL));
