@@ -10,7 +10,7 @@
  * Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with the program; if not, see <http://www.gnu.org/licenses/>  
+ * License along with the program; if not, see <http://www.gnu.org/licenses/>
  *
  *
  * Authors:
@@ -26,22 +26,19 @@
 
 #include "e-activity-handler.h"
 
-#include <gtk/gtksignal.h>
-#include <gdk-pixbuf/gdk-pixbuf.h>
-
+#include <gtk/gtk.h>
 #include <glib/gi18n.h>
-#include <libgnomeui/gnome-popup-menu.h>
+#include <gdk-pixbuf/gdk-pixbuf.h>
 
 #include <misc/e-popup-menu.h>
 
 #define ICON_SIZE 16
 
-
 struct _ActivityInfo {
-	char *component_id;
-	int error_type;
+	gchar *component_id;
+	gint error_type;
 	guint id;
-	char *information;
+	gchar *information;
 	gboolean cancellable;
 	double progress;
 	GtkWidget *menu;
@@ -63,7 +60,7 @@ struct _EActivityHandlerPrivate {
 };
 
 /* In the status bar, we show only errors and info. Errors are pictured as warnings. */
-const char *icon_data [] = {"dialog-warning", "dialog-information"};
+const gchar *icon_data [] = {"dialog-warning", "dialog-information"};
 
 G_DEFINE_TYPE (EActivityHandler, e_activity_handler, G_TYPE_OBJECT)
 
@@ -71,7 +68,7 @@ G_DEFINE_TYPE (EActivityHandler, e_activity_handler, G_TYPE_OBJECT)
 
 static void handle_error (ETaskWidget *task);
 
-static unsigned int
+static guint
 get_new_activity_id (EActivityHandler *activity_handler)
 {
 	EActivityHandlerPrivate *priv;
@@ -84,10 +81,10 @@ get_new_activity_id (EActivityHandler *activity_handler)
 static GList *
 lookup_activity (GList *list,
 		 guint activity_id,
-		 int *order_number_return)
+		 gint *order_number_return)
 {
 	GList *p;
-	int i;
+	gint i;
 
 	for (p = list, i = 0; p != NULL; p = p->next, i ++) {
 		ActivityInfo *activity_info;
@@ -103,13 +100,12 @@ lookup_activity (GList *list,
 	return NULL;
 }
 
-
 /* ETaskWidget actions.  */
 
-static int
+static gint
 task_widget_button_press_event_callback (GtkWidget *widget,
 					 GdkEventButton *button_event,
-					 void *data)
+					 gpointer data)
 {
 	ActivityInfo *activity_info;
 
@@ -124,13 +120,12 @@ task_widget_button_press_event_callback (GtkWidget *widget,
 	return TRUE;
 }
 
-
 /* Creating and destroying ActivityInfos.  */
 
 static ActivityInfo *
-activity_info_new (const char *component_id,
+activity_info_new (const gchar *component_id,
 		   guint id,
-		   const char *information,
+		   const gchar *information,
 		   gboolean cancellable)
 {
 	ActivityInfo *info;
@@ -144,7 +139,7 @@ activity_info_new (const char *component_id,
 	info->menu           = NULL;
 	info->error          = NULL;
 	info->cancel_func    = NULL;
-	
+
 	return info;
 }
 
@@ -182,7 +177,6 @@ task_widget_new_from_activity_info (ActivityInfo *activity_info)
 	return E_TASK_WIDGET (widget);
 }
 
-
 /* Task Bar handling.  */
 
 static void
@@ -202,22 +196,22 @@ setup_task_bar (EActivityHandler *activity_handler,
 		if (info->error) {
 			/* Prepare to handle existing errors*/
 			GtkWidget *tool;
-			const char *stock;
+			const gchar *stock;
 
 			stock = info->error_type ? icon_data [1] : icon_data[0];
-			tool = e_task_widget_update_image (task_widget, (char *)stock, info->information);
+			tool = e_task_widget_update_image (task_widget, (gchar *)stock, info->information);
 			g_object_set_data ((GObject *) task_widget, "tool", tool);
 			g_object_set_data ((GObject *) task_widget, "error", info->error);
 			g_object_set_data ((GObject *) task_widget, "activity-handler", activity_handler);
 			g_object_set_data ((GObject *) task_widget, "activity", GINT_TO_POINTER(info->id));
 			g_object_set_data ((GObject *) task_widget, "error-type", GINT_TO_POINTER(info->error_type));
-			g_signal_connect_swapped (tool, "clicked", G_CALLBACK(handle_error), task_widget);			
+			g_signal_connect_swapped (tool, "clicked", G_CALLBACK(handle_error), task_widget);
 		}
 	}
 }
 
 static void
-task_bar_destroy_notify (void *data,
+task_bar_destroy_notify (gpointer data,
 			 GObject *task_bar_instance)
 {
 	EActivityHandler *activity_handler;
@@ -229,7 +223,6 @@ task_bar_destroy_notify (void *data,
 	priv->task_bars = g_slist_remove (priv->task_bars, task_bar_instance);
 }
 
-
 /* GObject methods.  */
 
 static void
@@ -292,13 +285,12 @@ e_activity_handler_init (EActivityHandler *activity_handler)
 	priv->next_activity_id = 1;
 	priv->activity_infos   = NULL;
 	priv->task_bars        = NULL;
-	priv->logger 	       = NULL;
+	priv->logger	       = NULL;
 	priv->error_timer      = 0;
 	priv->error_flush_interval = 0;
 	activity_handler->priv = priv;
 }
 
-
 EActivityHandler *
 e_activity_handler_new (void)
 {
@@ -306,7 +298,7 @@ e_activity_handler_new (void)
 }
 
 void
-e_activity_handler_set_error_flush_time (EActivityHandler *handler, int time)
+e_activity_handler_set_error_flush_time (EActivityHandler *handler, gint time)
 {
 	handler->priv->error_flush_interval = time;
 }
@@ -318,7 +310,7 @@ e_activity_handler_set_logger (EActivityHandler *handler, ELogger *logger)
 
 void
 e_activity_handler_set_message (EActivityHandler *activity_handler,
-				const char       *message)
+				const gchar       *message)
 {
 	EActivityHandlerPrivate *priv;
 	GSList *i;
@@ -362,14 +354,14 @@ e_activity_handler_attach_task_bar (EActivityHandler *activity_handler,
 }
 
 struct _cancel_wdata {
-	EActivityHandler *handler;	
+	EActivityHandler *handler;
 	ActivityInfo *info;
 	guint id;
 	void (*cancel)(gpointer);
 	gpointer data;
 };
 
-static void 
+static void
 cancel_wrapper (gpointer pdata)
 {
 	struct _cancel_wdata *data = (struct _cancel_wdata *) pdata;
@@ -378,10 +370,10 @@ cancel_wrapper (gpointer pdata)
 		/* Hide the error */
 		EActivityHandler *handler = data->handler;
 		ActivityInfo *info;
-		int order, len;
+		gint order, len;
 		GSList *sp;
 		GList *p = lookup_activity (handler->priv->activity_infos, data->id, &order);
-		e_logger_log (handler->priv->logger, E_LOG_ERROR, g_object_get_data (data->info->error, "primary"), 
+		e_logger_log (handler->priv->logger, E_LOG_ERROR, g_object_get_data (data->info->error, "primary"),
 						    g_object_get_data (data->info->error, "secondary"));
 		gtk_widget_destroy (data->info->error);
 		data->info->error = NULL;
@@ -390,7 +382,7 @@ cancel_wrapper (gpointer pdata)
 			ETaskBar *task_bar;
 
 			task_bar = E_TASK_BAR (sp->data);
-			e_task_bar_remove_task_from_id (task_bar, info->id);	
+			e_task_bar_remove_task_from_id (task_bar, info->id);
 		}
 		activity_info_free (info);
 		len = g_list_length (handler->priv->activity_infos);
@@ -406,15 +398,15 @@ cancel_wrapper (gpointer pdata)
 
 /* CORBA methods.  */
 guint  e_activity_handler_cancelable_operation_started  (EActivityHandler *activity_handler,
-						      const char       *component_id,
-					      	      const char       *information,
-					      	      gboolean          cancellable,
+						      const gchar       *component_id,
+						      const gchar       *information,
+						      gboolean          cancellable,
 						      void (*cancel_func)(gpointer),
 						      gpointer user_data)
 {
 	EActivityHandlerPrivate *priv;
 	ActivityInfo *activity_info;
-	unsigned int activity_id;
+	guint activity_id;
 	GSList *p;
 	struct _cancel_wdata *data;
 	gboolean bfree = FALSE;
@@ -451,13 +443,13 @@ guint  e_activity_handler_cancelable_operation_started  (EActivityHandler *activ
 
 guint
 e_activity_handler_operation_started (EActivityHandler *activity_handler,
-				      const char *component_id,
-				      const char *information,
+				      const gchar *component_id,
+				      const gchar *information,
 				      gboolean cancellable)
 {
 	EActivityHandlerPrivate *priv;
 	ActivityInfo *activity_info;
-	unsigned int activity_id;
+	guint activity_id;
 	GSList *p;
 
 	priv = activity_handler->priv;
@@ -483,15 +475,15 @@ handle_error (ETaskWidget *task)
 	GtkWidget *tool, *error;
 	EActivityHandler *activity_handler;
 	guint id;
-	int error_type  = GPOINTER_TO_INT((g_object_get_data ((GObject *) task, "error-type")));
+	gint error_type  = GPOINTER_TO_INT((g_object_get_data ((GObject *) task, "error-type")));
 	tool = g_object_get_data ((GObject *) task, "tool");
 	error = g_object_get_data ((GObject *) task, "error");
 	activity_handler = g_object_get_data ((GObject *) task, "activity-handler");
 	id = GPOINTER_TO_UINT (g_object_get_data ((GObject *) task, "activity"));
 	e_activity_handler_operation_finished (activity_handler, id);
 	gtk_widget_show (error);
-	e_logger_log (activity_handler->priv->logger, error_type, 
-		      g_object_get_data ((GObject *) error, "primary"), 
+	e_logger_log (activity_handler->priv->logger, error_type,
+		      g_object_get_data ((GObject *) error, "primary"),
 				    g_object_get_data ((GObject *) error, "secondary"));
 }
 
@@ -501,7 +493,7 @@ error_cleanup (EActivityHandler *activity_handler)
 	EActivityHandlerPrivate *priv = activity_handler->priv;
 	GList *p, *node;
 	GSList *sp;
-	int i;
+	gint i;
 	time_t now = time (NULL);
 	gboolean berror = FALSE;
 
@@ -513,9 +505,14 @@ error_cleanup (EActivityHandler *activity_handler)
 			berror = TRUE;
 		if (info->error && info->error_time && (now - info->error_time) > 5 ) {
 			/* Error older than wanted time. So cleanup */
-			e_logger_log (priv->logger, info->error_type, g_object_get_data (info->error, "primary"), 
+			e_logger_log (priv->logger, info->error_type, g_object_get_data (info->error, "primary"),
 						    g_object_get_data (info->error, "secondary"));
-			gtk_widget_destroy (info->error);
+
+			if (GTK_IS_DIALOG (info->error))
+				gtk_dialog_response (GTK_DIALOG (info->error), GTK_RESPONSE_CLOSE);
+			else
+				gtk_widget_destroy (info->error);
+
 			node = p;
 			p = p->next;
 
@@ -527,7 +524,7 @@ error_cleanup (EActivityHandler *activity_handler)
 			}
 			activity_info_free (info);
 			priv->activity_infos = g_list_remove_link (priv->activity_infos, node);
-		
+
 		} else
 			p = p->next;
 	}
@@ -538,16 +535,16 @@ error_cleanup (EActivityHandler *activity_handler)
 
 guint
 e_activity_handler_make_error (EActivityHandler *activity_handler,
-				      const char *component_id,
-				      int error_type,
+				      const gchar *component_id,
+				      gint error_type,
 				      GtkWidget  *error)
 {
 	EActivityHandlerPrivate *priv;
 	ActivityInfo *activity_info;
-	unsigned int activity_id;
+	guint activity_id;
 	GSList *p;
-	char *information = g_object_get_data((GObject *) error, "primary");
-	const char *img;
+	gchar *information = g_object_get_data((GObject *) error, "primary");
+	const gchar *img;
 
 	priv = activity_handler->priv;
 	activity_id = get_new_activity_id (activity_handler);
@@ -556,7 +553,7 @@ e_activity_handler_make_error (EActivityHandler *activity_handler,
 	activity_info->error = error;
 	activity_info->error_time = time (NULL);
 	activity_info->error_type = error_type;
-	
+
 	img = error_type ? icon_data[1] : icon_data[0];
 	for (p = priv->task_bars; p != NULL; p = p->next) {
 		ETaskBar *task_bar;
@@ -564,17 +561,17 @@ e_activity_handler_make_error (EActivityHandler *activity_handler,
 		GtkWidget *tool;
 
 		task_bar = E_TASK_BAR (p->data);
-		task_widget = task_widget_new_from_activity_info (activity_info); 
+		task_widget = task_widget_new_from_activity_info (activity_info);
 		task_widget->id = activity_id;
 		e_task_bar_prepend_task (E_TASK_BAR (p->data), task_widget);
-		
-		tool = e_task_widget_update_image (task_widget, (char *)img, information);
+
+		tool = e_task_widget_update_image (task_widget, (gchar *)img, information);
 		g_object_set_data ((GObject *) task_widget, "tool", tool);
 		g_object_set_data ((GObject *) task_widget, "error", error);
 		g_object_set_data ((GObject *) task_widget, "activity-handler", activity_handler);
 		g_object_set_data ((GObject *) task_widget, "activity", GINT_TO_POINTER(activity_id));
 		g_object_set_data ((GObject *) task_widget, "error-type", GINT_TO_POINTER(error_type));
-		g_signal_connect_swapped (tool, "clicked", G_CALLBACK(handle_error), task_widget);		
+		g_signal_connect_swapped (tool, "clicked", G_CALLBACK(handle_error), task_widget);
 	}
 
 	priv->activity_infos = g_list_prepend (priv->activity_infos, activity_info);
@@ -594,7 +591,7 @@ e_activity_handler_operation_set_error(EActivityHandler *activity_handler,
 	ActivityInfo *activity_info;
 	GList *p;
 	GSList *sp;
-	int order_number;
+	gint order_number;
 
 	p = lookup_activity (priv->activity_infos, activity_id, &order_number);
 	if (p == NULL) {
@@ -618,7 +615,7 @@ e_activity_handler_operation_set_error(EActivityHandler *activity_handler,
 		if (!task_widget)
 			continue;
 
-		tool = e_task_widget_update_image (task_widget, (char *)icon_data[0], g_object_get_data ((GObject *) error, "primary"));
+		tool = e_task_widget_update_image (task_widget, (gchar *)icon_data[0], g_object_get_data ((GObject *) error, "primary"));
 		g_object_set_data ((GObject *) task_widget, "tool", tool);
 		g_object_set_data ((GObject *) task_widget, "error", error);
 		g_object_set_data ((GObject *) task_widget, "activity-handler", activity_handler);
@@ -634,14 +631,14 @@ e_activity_handler_operation_set_error(EActivityHandler *activity_handler,
 void
 e_activity_handler_operation_progressing (EActivityHandler *activity_handler,
 					  guint activity_id,
-					  const char *information,
+					  const gchar *information,
 					  double progress)
 {
 	EActivityHandlerPrivate *priv = activity_handler->priv;
 	ActivityInfo *activity_info;
 	GList *p;
 	GSList *sp;
-	int order_number;
+	gint order_number;
 
 	p = lookup_activity (priv->activity_infos, activity_id, &order_number);
 	if (p == NULL) {
@@ -676,7 +673,7 @@ e_activity_handler_operation_finished (EActivityHandler *activity_handler,
 	EActivityHandlerPrivate *priv = activity_handler->priv;
 	GList *p;
 	GSList *sp;
-	int order_number;
+	gint order_number;
 
 	p = lookup_activity (priv->activity_infos, activity_id, &order_number);
 	if (p == NULL) {
